Cheshire3 Object Model - Extractor
==================================

.. _objects-extractor-api:

API
---

.. autoclass:: cheshire3.baseObjects.Extractor
   :members:


.. _objects-extractor-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.extractor.SimpleExtractor

.. autoclass:: cheshire3.extractor.TeiExtractor

.. autoclass:: cheshire3.extractor.SpanXPathExtractor
